@@ -1,5 +1,5 @@
 /* OpenCP Module Player
- * copyright (c) 2021-'22 Stian Skjelstad <stian.skjelstad@gmail.com>
+ * copyright (c) 2021-'24 Stian Skjelstad <stian.skjelstad@gmail.com>
  *
  * Code to decompress UNIX Z compressed files
  *
@@ -188,64 +188,6 @@ static int Z_ocpfilehandle_seek_set (struct ocpfilehandle_t *_s, int64_t pos)
 	return 0;
 }
 
-static int Z_ocpfilehandle_seek_cur (struct ocpfilehandle_t *_s, int64_t pos)
-{
-	struct Z_ocpfilehandle_t *s = (struct Z_ocpfilehandle_t *)_s;
-
-	if (pos <= 0)
-	{
-		if (pos == INT64_MIN) return -1; /* we never have files this size */
-		if ((-pos) > s->pos) return -1;
-		s->pos += pos;
-	} else {
-		/* check for overflow */
-		if ((int64_t)(pos + s->pos) < 0) return -1;
-
-		if (s->owner->filesize_pending)
-		{
-			if (_s->filesize (_s) == FILESIZE_ERROR) /* force the size to be calculated */
-			{
-				s->error = 1;
-				return -1;
-			}
-		}
-
-		if ((pos + s->pos) > s->owner->uncompressed_filesize) return -1;
-		s->pos += pos;
-	}
-
-	s->error = 0;
-
-	return 0;
-}
-
-static int Z_ocpfilehandle_seek_end (struct ocpfilehandle_t *_s, int64_t pos)
-{
-	struct Z_ocpfilehandle_t *s = (struct Z_ocpfilehandle_t *)_s;
-
-	if (pos > 0) return -1;
-
-	if (pos == INT64_MIN) return -1; /* we never have files this size */
-
-	if (s->owner->filesize_pending)
-	{
-		if (_s->filesize (_s) == FILESIZE_ERROR) /* force the size to be calculated */
-		{
-			s->error = 1;
-			return -1;
-		}
-	}
-
-	if (pos < -(int64_t)(s->owner->uncompressed_filesize)) return -1;
-
-	s->pos = s->owner->uncompressed_filesize + pos;
-
-	s->error = 0;
-
-	return 0;
-}
-
-
 static uint64_t Z_ocpfilehandle_getpos (struct ocpfilehandle_t *_s)
 {
 	struct Z_ocpfilehandle_t *s = (struct Z_ocpfilehandle_t *)_s;
@@ -446,9 +388,8 @@ static struct ocpfilehandle_t *Z_ocpfile_open (struct ocpfile_t *_s)
 	ocpfilehandle_t_fill (&retval->head,
 	                       Z_ocpfilehandle_ref,
 	                       Z_ocpfilehandle_unref,
+	                       _s,
 	                       Z_ocpfilehandle_seek_set,
-	                       Z_ocpfilehandle_seek_cur,
-	                       Z_ocpfilehandle_seek_end,
 	                       Z_ocpfilehandle_getpos,
 	                       Z_ocpfilehandle_eof,
 	                       Z_ocpfilehandle_error,
@@ -457,7 +398,9 @@ static struct ocpfilehandle_t *Z_ocpfile_open (struct ocpfile_t *_s)
 	                       Z_ocpfilehandle_filesize,
 	                       Z_ocpfilehandle_filesize_ready,
 	                       0, /* filename_override */
-	                       dirdbRef (s->head.dirdb_ref, dirdb_use_filehandle));
+	                       dirdbRef (s->head.dirdb_ref, dirdb_use_filehandle),
+	                       1
+	);
 
 	retval->owner = s;
 	s->head.ref (&s->head);
@@ -471,8 +414,6 @@ static struct ocpfilehandle_t *Z_ocpfile_open (struct ocpfile_t *_s)
 		return 0;
 	}
 
-	retval->head.refcount = 1;
-
 	return &retval->head;
 }
 
@@ -777,7 +718,8 @@ static struct ocpdir_t *Z_check_steal (struct ocpfile_t *s, const uint32_t dirdb
 	                s->dirdb_ref,
 	                1, /* refcount */
 	                1, /* is_archive */
-	                0  /* is_playlist */);
+	                0, /* is_playlist */
+	                s->compression);
 
 	s->parent->ref (s->parent);
 	dirdbRef (s->dirdb_ref, dirdb_use_dir);
@@ -792,7 +734,8 @@ static struct ocpdir_t *Z_check_steal (struct ocpfile_t *s, const uint32_t dirdb
 	                 0, /* filename_override */
 	                 dirdb_ref,
 	                 0, /* refcount */
-	                 0  /* is_nodetect */);
+	                 0, /* is_nodetect */
+	                 COMPRESSION_ADD_STREAM(s->compression));
 
 	retval->child.filesize_pending = 1;
 	retval->child.uncompressed_filesize = 0;
